@@ -25,19 +25,14 @@ GisTools allows some of the following operations:
 """
 
 # __all__ = []
-from shapely.geometry import LineString, MultiLineString, Polygon, MultiPolygon, Point, MultiPoint
 
-__version__ = '0.16.23'
+__version__ = '0.17.8'
 __author__ = 'Benjamin Pillot'
 __copyright__ = 'Copyright 2020, Benjamin Pillot'
 __email__ = 'benjaminpillot@riseup.net'
-__licence__ = "GNU GPL v3.0"
+__licence__ = "MIT"
 
 # from gistools.layer import *
 # from gistools.raster import *
 # from gistools.network import *
 # from gistools.stats import *
-
-
-GEOMETRY_CLASS = {'linestring': (LineString, MultiLineString), 'polygon': (Polygon, MultiPolygon),
-                  'point': (Point, MultiPoint)}
