@@ -5,26 +5,20 @@
 More detailed description.
 """
 
-# __all__ = []
-# __version__ = '0.1'
-
 import numpy as np
 import networkx as nx
 
 from math import sqrt as msqrt
 
+from numba import njit
 from shapely.errors import TopologicalError
 from shapely.geometry import MultiPolygon, GeometryCollection, Polygon, box, LineString, \
     Point, MultiLineString, JOIN_STYLE
 from shapely.ops import cascaded_union, linemerge, unary_union, transform
-from utils.check.type import is_iterable, type_assert
 
 from gistools.coordinates import r_tree_idx
 from gistools.graph import part_graph
-
-__author__ = 'Benjamin Pillot'
-__copyright__ = 'Copyright 2018, Benjamin Pillot'
-__email__ = 'benjaminpillot@riseup.net'
+from gistools.utils.check.type import is_iterable, type_assert
 
 
 def add_points_to_line(line, threshold):
@@ -37,7 +31,8 @@ def add_points_to_line(line, threshold):
     return linemerge(cut_(line, threshold))
 
 
-def aggregate_partitions(polygons, weights, nparts, division, weight_attr, split, recursive, **metis_options):
+def aggregate_partitions(polygons, weights, nparts, division,
+                         weight_attr, split, recursive, **metis_options):
     """ Aggregate polygons into partitions
 
     :param polygons: polygons to aggregate
@@ -52,7 +47,8 @@ def aggregate_partitions(polygons, weights, nparts, division, weight_attr, split
     """
     if "contig" not in metis_options.keys():
         metis_options["contig"] = False
-    graph = polygon_collection_to_graph(polygons, weights, split, metis_options["contig"], weight_attr)
+    graph = polygon_collection_to_graph(polygons, weights, split,
+                                        metis_options["contig"], weight_attr)
     tpweights = [(d,) for d in division]
     partition = part_graph(graph, nparts, weight_attr, tpweights, recursive, **metis_options)
 
@@ -60,7 +56,8 @@ def aggregate_partitions(polygons, weights, nparts, division, weight_attr, split
     return explode([no_artifact_unary_union([polygons[n] for n in part]) for part in partition])
 
 
-def area_partition_polygon(polygon, unit_area, disaggregation_factor, precision, recursive, split, **metis_options):
+def area_partition_polygon(polygon, unit_area, disaggregation_factor, precision,
+                           recursive, split, **metis_options):
     """ Partition polygon into a subset of polygons of equal area
 
     :param polygon: polygon intended to be partitioned
@@ -87,7 +84,8 @@ def area_partition_polygon(polygon, unit_area, disaggregation_factor, precision,
 
     area = [int(poly.area / precision) for poly in split_poly]
 
-    return aggregate_partitions(split_poly, area, nparts, division, "area", split, recursive, **metis_options)
+    return aggregate_partitions(split_poly, area, nparts, division, "area",
+                                split, recursive, **metis_options)
 
 
 def centroid(point_collection):
@@ -313,7 +311,8 @@ def hexana(polygon, threshold):
 
 
 # Thanks to https://gist.github.com/urschrei/17cf0be92ca90a244a91
-def honeycomb(startx, starty, endx, endy, radius=None, area=None):
+@njit()
+def honeycomb_nb(startx, starty, endx, endy, radius):
     """
     Calculate a grid of hexagon coordinates of the given radius
     given lower-left and upper-right coordinates
@@ -326,8 +325,6 @@ def honeycomb(startx, starty, endx, endy, radius=None, area=None):
 
     You will probably want to use projected coordinates for this
     """
-    if not radius:
-        radius = msqrt(area / (2*msqrt(3)))
 
     # calculate side length given radius
     sl = (2 * radius) * np.tan(np.pi / 6)
@@ -353,9 +350,7 @@ def honeycomb(startx, starty, endx, endy, radius=None, area=None):
     xoffset = b
     yoffset = 3 * p
 
-    polygons = []
     row = 1
-    counter = 0
 
     while starty < endy:
         if row % 2 == 0:
@@ -383,13 +378,33 @@ def honeycomb(startx, starty, endx, endy, radius=None, area=None):
                 (p5x, p5y),
                 (p6x, p6y),
                 (p1x, p1y)]
-            polygons.append(Polygon(poly))
-            counter += 1
+            yield poly
             startx += w
         starty += yoffset
         row += 1
 
-    return polygons
+
+def honeycomb(startx, starty, endx, endy, radius=None, area=None):
+    """
+
+    Parameters
+    ----------
+    startx
+    starty
+    endx
+    endy
+    radius
+    area
+
+    Returns
+    -------
+
+    """
+
+    if not radius:
+        radius = msqrt(area / (2*msqrt(3)))
+
+    return (Polygon(poly) for poly in honeycomb_nb(startx, starty, endx, endy, radius))
 
 
 def intersecting_features(geometry, geometry_collection, r_tree=None):
